@@ -27,7 +27,7 @@
 /* Global variables                                        */
 
 /*we can support up to 128  lookup table types, looks enough*/
-const struct ci_lookup_table_type *lookup_tables_types[128]; 
+const struct ci_lookup_table_type *lookup_tables_types[128];
 int lookup_tables_types_num = 0;
 
 /*********************************************************************/
@@ -35,92 +35,90 @@ int lookup_tables_types_num = 0;
 
 struct ci_lookup_table_type *ci_lookup_table_type_register( struct ci_lookup_table_type *lt_type)
 {
-    if(lookup_tables_types_num >= 128) {
-	ci_debug_printf(1,"c-icap does not support more than 128 loookup table types");
-	return NULL;
+    if (lookup_tables_types_num >= 128) {
+        ci_debug_printf(1,"c-icap does not support more than 128 loookup table types");
+        return NULL;
     }
-    lookup_tables_types[lookup_tables_types_num++]=lt_type;
+    lookup_tables_types[lookup_tables_types_num++] = lt_type;
     return lt_type;
 }
 
 void ci_lookup_table_type_unregister( struct ci_lookup_table_type *lt_type)
 {
     int i;
-    for(i=0; lookup_tables_types[i] != lt_type && i < lookup_tables_types_num; i++);
+    for (i = 0; lookup_tables_types[i] != lt_type && i < lookup_tables_types_num; i++);
 
-    if(i<lookup_tables_types_num) {
-	lookup_tables_types_num--;
-	for(; i < lookup_tables_types_num; i++)
-	    lookup_tables_types[i] = lookup_tables_types[i+1];
+    if (i<lookup_tables_types_num) {
+        lookup_tables_types_num--;
+        for (; i < lookup_tables_types_num; i++)
+            lookup_tables_types[i] = lookup_tables_types[i+1];
     }
 }
 
 const struct ci_lookup_table_type *ci_lookup_table_type_search(const char *type)
 {
     int i;
-    for(i=0;i<lookup_tables_types_num;i++) {
-	if (strcmp(type,lookup_tables_types[i]->type) == 0)
-	    return lookup_tables_types[i];
+    for (i = 0; i<lookup_tables_types_num; i++) {
+        if (strcmp(type,lookup_tables_types[i]->type) == 0)
+            return lookup_tables_types[i];
     }
     return NULL;
 }
 
 static const void * lookup_table_get_row(struct ci_lookup_table *table, const void *key, const char *columns[], void ***vals);
 struct ci_lookup_table *ci_lookup_table_create_ext(const char *table,
-						   const ci_type_ops_t *key_ops,
-						   const ci_type_ops_t *val_ops, 
-						   ci_mem_allocator_t *allocator)
+        const ci_type_ops_t *key_ops,
+        const ci_type_ops_t *val_ops,
+        ci_mem_allocator_t *allocator)
 {
     char *ttype,*path,*args,*s;
     const struct ci_lookup_table_type *lt_type;
     struct ci_lookup_table *lt;
     char *stable = strdup(table);
-    if(!stable){
-	/*A debug message.....*/
-	return NULL;
+    if (!stable) {
+        /*A debug message.....*/
+        return NULL;
     }
-    
+
     /*Normaly the table has the form tabletype:/path/{args}*/
-    s = index(stable,':'); 
-    
+    s = index(stable,':');
+
     if (!s) { /*Then it is a simple text file*/
-	ttype = "file";
-	path = stable;
-	args = NULL;
-    }
-    else {
-	ttype = stable;
-	path = s+1;
-	*s = '\0';	
-	s = index(path,'{');
-	if (s) {
-	    *s = '\0'; /* path ends here */
-	    args = s+1; /*args start here */
-	    
-	    if ((s = index(args,'}'))) *s = '\0'; /*else args is all the remains string */
-	}
-	else /*No args*/
-	    args = NULL;
+        ttype = "file";
+        path = stable;
+        args = NULL;
+    } else {
+        ttype = stable;
+        path = s+1;
+        *s = '\0';
+        s = index(path,'{');
+        if (s) {
+            *s = '\0'; /* path ends here */
+            args = s+1; /*args start here */
+
+            if ((s = index(args,'}'))) *s = '\0'; /*else args is all the remains string */
+        } else /*No args*/
+            args = NULL;
     }
     lt_type = ci_lookup_table_type_search(ttype);
     if (!lt_type || !lt_type->open) {
-	ci_debug_printf(1,"Not lookuptable of type :%s!!!\n", ttype);
-	free(stable);
-	return NULL;
+        ci_debug_printf(1,"Not lookuptable of type :%s!!!\n", ttype);
+        free(stable);
+        return NULL;
     }
 
     lt = malloc(sizeof(struct ci_lookup_table));
-    if(!lt) {
-	ci_debug_printf(1,"memory allocation error!!");
-	free(stable);
-	return NULL;
+    if (!lt) {
+        ci_debug_printf(1,"memory allocation error!!");
+        free(stable);
+        return NULL;
     }
 
-    lt->path=strdup(path);
-    if(args)
-      lt->args=strdup(args);
+    lt->path = strdup(path);
+    if (args)
+        lt->args = strdup(args);
     else
-      lt->args=NULL;
+        lt->args = NULL;
 
     free(stable);
 
@@ -136,18 +134,18 @@ struct ci_lookup_table *ci_lookup_table_create_ext(const char *table,
     lt->release_result = lt_type->release_result;
     lt->allocator = allocator;
     lt->_lt_type = lt_type;
-    lt->data = NULL; 
+    lt->data = NULL;
 
-    return lt;    
+    return lt;
 }
 
-struct ci_lookup_table *ci_lookup_table_create(const char *table) 
+struct ci_lookup_table *ci_lookup_table_create(const char *table)
 {
     ci_mem_allocator_t *allocator;
     struct ci_lookup_table *lt;
     allocator = ci_create_os_allocator();
-    if(!allocator)
-	return NULL;
+    if (!allocator)
+        return NULL;
 
     lt = ci_lookup_table_create_ext(table, &ci_str_ops, &ci_str_ops, allocator);
     if (!lt)
@@ -158,20 +156,20 @@ struct ci_lookup_table *ci_lookup_table_create(const char *table)
 void ci_lookup_table_destroy(struct ci_lookup_table *lt)
 {
     if (!lt)
-	return;
-    
+        return;
+
     lt->close(lt);
     free(lt->path);
-    if(lt->args)
-	free(lt->args);
-    if(lt->allocator)
-	ci_mem_allocator_destroy(lt->allocator);
+    if (lt->args)
+        free(lt->args);
+    if (lt->allocator)
+        ci_mem_allocator_destroy(lt->allocator);
     free(lt);
 }
 
 void * ci_lookup_table_open(struct ci_lookup_table *table)
 {
-     if (!table->_lt_type || !table->open) {
+    if (!table->_lt_type || !table->open) {
         ci_debug_printf(1, "lookup_table of type  %s is corrupted (\"open\" method missing)!\n", table->type);
         return NULL;
     }
@@ -215,7 +213,7 @@ const void * lookup_table_get_row(struct ci_lookup_table *table, const void *key
         return NULL;
     }
 
-    for (i=0; i < 1024 && columns[i] != NULL; i++) {
+    for (i = 0; i < 1024 && columns[i] != NULL; i++) {
         if (NULL == ci_str_vector_search(table->col_names, columns[i])) {
             ci_debug_printf(1, "lookup_table :%s does not has column %s\n", table->type, columns[i]);
             return NULL;
@@ -231,14 +229,15 @@ const char * ci_lookup_table_get_row(struct ci_lookup_table *table, const char *
         ci_debug_printf(1, "lookup_table of type  %s does not support search with string like keys!\n", table->type);
         return NULL;
     }
-    
+
     return (const char *) lookup_table_get_row(table, (const void *)key, columns, (void ***)vals);
 }
 
 extern struct ci_lookup_table_type file_table_type;
 extern struct ci_lookup_table_type hash_table_type;
 extern struct ci_lookup_table_type regex_table_type;
-CI_DECLARE_FUNC(void) init_internal_lookup_tables(){
+CI_DECLARE_FUNC(void) init_internal_lookup_tables()
+{
     ci_lookup_table_type_register(&file_table_type);
     ci_lookup_table_type_register(&hash_table_type);
     ci_lookup_table_type_register(&regex_table_type);
