@@ -1,10 +1,11 @@
-#include "common.h" 
+#include "common.h"
 #include "c-icap.h"
 #include "module.h"
 #include "lookup_table.h"
 #include "net_io.h"
 #include "cache.h"
 #include "debug.h"
+#include "util.h"
 #include "common.h"
 
 
@@ -21,12 +22,12 @@ CI_DECLARE_MOD_DATA common_module_t module = {
 
 
 
-void *dnsbl_table_open(struct ci_lookup_table *table); 
+void *dnsbl_table_open(struct ci_lookup_table *table);
 void  dnsbl_table_close(struct ci_lookup_table *table);
 void *dnsbl_table_search(struct ci_lookup_table *table, void *key, void ***vals);
 void  dnsbl_table_release_result(struct ci_lookup_table *table_data,void **val);
 
-struct ci_lookup_table_type dnsbl_table_type={
+struct ci_lookup_table_type dnsbl_table_type = {
     dnsbl_table_open,
     dnsbl_table_close,
     dnsbl_table_search,
@@ -67,12 +68,12 @@ void *dnsbl_table_open(struct ci_lookup_table *table)
     int i;
 
     if (strlen(table->path) >= CI_MAXHOSTNAMELEN ) {
-         ci_debug_printf(1, "dnsbl_table_open: too long domain name: %s\n",
+        ci_debug_printf(1, "dnsbl_table_open: too long domain name: %s\n",
                         table->path);
         return NULL;
     }
 
-    if (table->key_ops != &ci_str_ops || table->val_ops!= &ci_str_ops) {
+    if (table->key_ops != &ci_str_ops || table->val_ops != &ci_str_ops) {
         ci_debug_printf(1, "dnsbl_table_open:  Only searching with strings and returning strings supported\n");
         return NULL;
     }
@@ -89,7 +90,7 @@ void *dnsbl_table_open(struct ci_lookup_table *table)
         if ((args = ci_parse_key_value_list(table->args, ','))) {
             for (i = 0; (arg = ci_dyn_array_get_item(args, i)) != NULL; ++i) {
                 ci_debug_printf(5, "Table argument %s:%s\n", arg->name, (char *)arg->value);
-                if(strcasecmp(arg->name, "cache") == 0) {
+                if (strcasecmp(arg->name, "cache") == 0) {
                     if (strcasecmp(arg->value, "no") == 0)
                         use_cache = NULL;
                     else
@@ -118,7 +119,7 @@ void *dnsbl_table_open(struct ci_lookup_table *table)
     } else
         dnsbl_data->cache = NULL;
 
-    table->data = dnsbl_data; 
+    table->data = dnsbl_data;
 
     /*Must released before exit, we have pointes pointing on args array items*/
     if (args)
@@ -128,11 +129,11 @@ void *dnsbl_table_open(struct ci_lookup_table *table)
 
 void  dnsbl_table_close(struct ci_lookup_table *table)
 {
-     struct dnsbl_data *dnsbl_data = table->data;
-     table->data = NULL;
-     if (dnsbl_data->cache)
-         ci_cache_destroy(dnsbl_data->cache);
-     free(dnsbl_data);
+    struct dnsbl_data *dnsbl_data = table->data;
+    table->data = NULL;
+    if (dnsbl_data->cache)
+        ci_cache_destroy(dnsbl_data->cache);
+    free(dnsbl_data);
 }
 
 static ci_vector_t  *resolv_hostname(char *hostname);
@@ -144,14 +145,14 @@ void *dnsbl_table_search(struct ci_lookup_table *table, void *key, void ***vals)
     size_t v_size;
     struct dnsbl_data *dnsbl_data = table->data;
 
-    if(table->key_ops != &ci_str_ops) {
-	ci_debug_printf(1,"Only keys of type string allowed in this type of table:\n");
-	return NULL;
+    if (table->key_ops != &ci_str_ops) {
+        ci_debug_printf(1,"Only keys of type string allowed in this type of table:\n");
+        return NULL;
     }
     server = (char *)key;
 
     if (dnsbl_data->cache && ci_cache_search(dnsbl_data->cache, server, (void **)&v, NULL, &ci_cache_read_vector_val)) {
-	ci_debug_printf(6,"dnsbl_table_search: cache hit for %s value %p\n", server,  v);
+        ci_debug_printf(6,"dnsbl_table_search: cache hit for %s value %p\n", server,  v);
         if (!v) {
             *vals = NULL;
             return NULL;
@@ -167,7 +168,7 @@ void *dnsbl_table_search(struct ci_lookup_table *table, void *key, void ***vals)
         v_size =  v != NULL ? ci_cache_store_vector_size(v) : 0;
         ci_cache_update(dnsbl_data->cache, server, v, v_size, ci_cache_store_vector_val);
     }
-    
+
     if (!v)
         return NULL;
 
@@ -193,27 +194,27 @@ static ci_vector_t  *resolv_hostname(char *hostname)
     ci_sockaddr_t addr;
     char buf[256];
 
-     memset(&hints, 0, sizeof(hints));
-     hints.ai_family = AF_UNSPEC;
-     hints.ai_socktype = SOCK_STREAM;
-     hints.ai_protocol = 0;
-     if ((ret = getaddrinfo(hostname, NULL, &hints, &res)) != 0) {
-	 ci_debug_printf(5, "Error geting addrinfo:%s\n", gai_strerror(ret));
-	 return NULL;
-     }
+    memset(&hints, 0, sizeof(hints));
+    hints.ai_family = AF_UNSPEC;
+    hints.ai_socktype = SOCK_STREAM;
+    hints.ai_protocol = 0;
+    if ((ret = getaddrinfo(hostname, NULL, &hints, &res)) != 0) {
+        ci_debug_printf(5, "Error geting addrinfo:%s\n", gai_strerror(ret));
+        return NULL;
+    }
 
-     if (res)
-         vect = ci_str_vector_create(1024);
+    if (res)
+        vect = ci_str_vector_create(1024);
 
-     if (vect) {
-         for(cur = res; cur != NULL; cur = cur->ai_next){
-             memcpy(&(addr.sockaddr), cur->ai_addr, CI_SOCKADDR_SIZE);
-             ci_fill_sockaddr(&addr);
-             if (ci_sockaddr_t_to_ip(&addr, buf, sizeof(buf)))
-                 (void)ci_str_vector_add(vect, buf);
-         }
-         freeaddrinfo(res);
-     }
+    if (vect) {
+        for (cur = res; cur != NULL; cur = cur->ai_next) {
+            memcpy(&(addr.sockaddr), cur->ai_addr, CI_SOCKADDR_SIZE);
+            ci_fill_sockaddr(&addr);
+            if (ci_sockaddr_t_to_ip(&addr, buf, sizeof(buf)))
+                (void)ci_str_vector_add(vect, buf);
+        }
+        freeaddrinfo(res);
+    }
 
-     return vect;
+    return vect;
 }
