@@ -122,7 +122,7 @@ struct ci_fmt_entry GlobalTable [] = {
     {"%>ih", "Icap request header", fmt_icap_req_head},
     {"%<ih", "Icap response header", fmt_icap_res_head},
     {"%ipl", "Icap preview length", fmt_req_preview_len},
-    
+
     {"%Ih", "Http bytes received", fmt_req_http_bytes_rcv},
     {"%Oh", "Http bytes sent", fmt_req_http_bytes_sent},
     {"%Ib", "Http body bytes received", fmt_req_body_bytes_rcv},
@@ -136,178 +136,172 @@ struct ci_fmt_entry GlobalTable [] = {
     {"%Sl", "Service log string", fmt_logstr},
     {"%Sa", "Attribute set by service", fmt_req_attribute},
     {"%%", "% sign", fmt_percent},
-    { NULL, NULL, NULL} 
+    { NULL, NULL, NULL}
 };
 
 int fmt_none(ci_request_t *req, char *buf,int len, const char *param)
 {
-  if (!len)
-     return 0;
+    if (!len)
+        return 0;
 
-  *buf = '-';
-   return 1;
+    *buf = '-';
+    return 1;
 }
 
 int fmt_percent(ci_request_t *req, char *buf,int len, const char *param)
 {
-   if (!len)
-      return 0;
-      
-  *buf = '%';
-   return 1;
+    if (!len)
+        return 0;
+
+    *buf = '%';
+    return 1;
 }
 
-unsigned int parse_directive(const char *var, 
-                     unsigned int *width,
-                     int *left_align, char *parameter)
+unsigned int parse_directive(const char *var,
+                             unsigned int *width,
+                             int *left_align, char *parameter)
 {
-   const char *s1;
-   int i = 0;
-   char *e;
-   s1 = var+1;
-   parameter[0] = '\0';
+    const char *s1;
+    int i = 0;
+    char *e;
+    s1 = var+1;
+    parameter[0] = '\0';
 
-   if (s1[0] == '-') {
-       *left_align = 1;
-       s1++;
-   }
-   else
-       *left_align = 0;
+    if (s1[0] == '-') {
+        *left_align = 1;
+        s1++;
+    } else
+        *left_align = 0;
 
-   *width = strtol(s1, &e, 10);
-   if (e == s1) {
-      *width = 0;
-   }
-   else
-      s1 = e;
+    *width = strtol(s1, &e, 10);
+    if (e == s1) {
+        *width = 0;
+    } else
+        s1 = e;
 
-   if (*s1 == '{') {
-       s1++;
-       i = 0;
-       while (*s1 && *s1!='}' && i < MAX_VARIABLE_SIZE -1 ) {
+    if (*s1 == '{') {
+        s1++;
+        i = 0;
+        while (*s1 && *s1!='}' && i < MAX_VARIABLE_SIZE -1 ) {
             parameter[i] = *s1;
             i++,s1++;
-       }
-       if (*s1 != '}')
-           return 0;
+        }
+        if (*s1 != '}')
+            return 0;
 
-       parameter[i] = '\0';
-       s1++;
-   }
-   return  s1-var;
+        parameter[i] = '\0';
+        s1++;
+    }
+    return  s1-var;
 }
 
 int check_directive( const char *var, const char *directive, int *directive_len)
 {
-   const char *s1, *s2;
-   s1 = var;
-   s2 = directive+1;
-   *directive_len = 0;
+    const char *s1, *s2;
+    s1 = var;
+    s2 = directive+1;
+    *directive_len = 0;
 
-   while (*s2) {
-       if (!s1)
-          return 0;
-       if (*s1 != *s2)
-          return 0;
+    while (*s2) {
+        if (!s1)
+            return 0;
+        if (*s1 != *s2)
+            return 0;
         s1++,s2++;
-   }
-   *directive_len = s1-var;
-   return 1; 
+    }
+    *directive_len = s1-var;
+    return 1;
 }
 
 struct ci_fmt_entry *check_tables(const char *var, struct ci_fmt_entry *u_table, int *directive_len, unsigned int *width, int *left_align, char *parameter)
 {
-   int i;
-   unsigned int params_len;
-   params_len = parse_directive(var, width, left_align, parameter);
-   for (i=0; GlobalTable[i].directive; i++) {
-       if(check_directive(var+params_len,GlobalTable[i].directive, directive_len)) {
-           *directive_len += params_len;
-           return &GlobalTable[i];
-       }
-   }
-   if (u_table) {
-       for (i=0; u_table[i].directive; i++) {
+    int i;
+    unsigned int params_len;
+    params_len = parse_directive(var, width, left_align, parameter);
+    for (i = 0; GlobalTable[i].directive; i++) {
+        if (check_directive(var+params_len,GlobalTable[i].directive, directive_len)) {
+            *directive_len += params_len;
+            return &GlobalTable[i];
+        }
+    }
+    if (u_table) {
+        for (i = 0; u_table[i].directive; i++) {
             if (check_directive(var+params_len, u_table[i].directive, directive_len)) {
                 *directive_len += params_len;
                 return &u_table[i];
             }
-       }
-   }
-   return NULL;
+        }
+    }
+    return NULL;
 }
 
 int ci_format_text(
-                 ci_request_t *req_data,
-                 const char *fmt,
-                 char *buffer, int len,
-                 struct ci_fmt_entry *user_table)
+    ci_request_t *req_data,
+    const char *fmt,
+    char *buffer, int len,
+    struct ci_fmt_entry *user_table)
 {
-   const char *s;
-   char *b, *lb;
-   struct ci_fmt_entry *fmte;
-   int directive_len, val_len, remains, left_align, i;
-   unsigned int width, space=0;
-   char parameter[MAX_VARIABLE_SIZE];
+    const char *s;
+    char *b, *lb;
+    struct ci_fmt_entry *fmte;
+    int directive_len, val_len, remains, left_align, i;
+    unsigned int width, space = 0;
+    char parameter[MAX_VARIABLE_SIZE];
 
-   lb = NULL;
-   s = fmt;
-   b = buffer;
-   remains = len - 1;
-   while (*s && remains > 0) {
-     if (*s == '%') {
-       fmte = check_tables(s, user_table, &directive_len, 
-                           &width, &left_align, parameter);
-       ci_debug_printf(7,"Width: %d, Parameter:%s\n", width, parameter);
-       if (width != 0) 
-            space = width = (remains<width?remains:width);
-       else
-            space = remains;
-       if(fmte != NULL) { 
-            if (width) {
-                if (left_align) {
-                    val_len=fmte->format(req_data, b, space, parameter);
-                    if (val_len <=0)  val_len = fmt_none(req_data, b, space, parameter);
-                    
-                    if (val_len > space) val_len = space;
-                    b += val_len;
-                    for (i=0; i < width-val_len; i++) b[i]=' ';
-                    b += width-val_len;
-                }
-                else if ((lb = malloc((space+1)*sizeof(char))) != NULL) {
-                    val_len=fmte->format(req_data, lb, space, parameter);
-                    if (val_len <=0)  val_len = fmt_none(req_data, lb, space, parameter);
+    lb = NULL;
+    s = fmt;
+    b = buffer;
+    remains = len - 1;
+    while (*s && remains > 0) {
+        if (*s == '%') {
+            fmte = check_tables(s, user_table, &directive_len,
+                                &width, &left_align, parameter);
+            ci_debug_printf(7,"Width: %d, Parameter:%s\n", width, parameter);
+            if (width != 0)
+                space = width = (remains<width?remains:width);
+            else
+                space = remains;
+            if (fmte != NULL) {
+                if (width) {
+                    if (left_align) {
+                        val_len = fmte->format(req_data, b, space, parameter);
+                        if (val_len <= 0) val_len = fmt_none(req_data, b, space, parameter);
+
+                        if (val_len > space) val_len = space;
+                        b += val_len;
+                        for (i = 0; i < width-val_len; i++) b[i]=' ';
+                        b += width-val_len;
+                    } else if ((lb = malloc((space+1)*sizeof(char))) != NULL) {
+                        val_len = fmte->format(req_data, lb, space, parameter);
+                        if (val_len <= 0) val_len = fmt_none(req_data, lb, space, parameter);
+
+                        if (val_len > space) val_len = space;
+                        for (i = 0; i < width-val_len; i++) b[i] = ' ';
+                        b += width-val_len;
+                        for (i = 0; i < val_len; i++) b[i] = lb[i];
+                        b += val_len;
+                        free(lb);
+                        lb = NULL;
+                    }
+                    /*else allocation failed! Just ignore?????*/
+
+                    remains -= width;
+                } else {
+                    val_len = fmte->format(req_data, b, space, parameter);
+                    if (val_len <= 0) val_len = fmt_none(req_data, b, space, parameter);
 
                     if (val_len > space) val_len = space;
-                    for (i=0; i < width-val_len; i++) b[i]=' ';
-                    b += width-val_len; 
-                    for (i=0; i < val_len; i++) b[i]=lb[i];
                     b += val_len;
-                    free(lb);
-                    lb = NULL;
+                    remains -= val_len;
                 }
-                /*else allocation failed! Just ignore?????*/
-
-                remains -= width;
-            } 
-             else {
-		val_len=fmte->format(req_data, b, space, parameter);
-                if (val_len <=0)  val_len = fmt_none(req_data, b, space, parameter);
-
-                if (val_len > space) val_len = space;
-                b += val_len; 
-                remains -= val_len;
-             }
-            s += directive_len;
-       }
-       else
-         *b++ = *s++, remains--; 
-     }
-     else 
-        *b++ = *s++, remains--;
-   }
-   *b = '\0';
-   return len-remains;
+                s += directive_len;
+            } else
+                *b++ = *s++, remains--;
+        } else
+            *b++ = *s++, remains--;
+    }
+    *b = '\0';
+    return len-remains;
 }
 
 
@@ -316,10 +310,10 @@ int ci_format_text(
 int fmt_remoteip(ci_request_t *req, char *buf,int len, const char *param)
 {
     if (len<CI_IPLEN)
-	return 0;
+        return 0;
 
     if (!ci_conn_remote_ip(req->connection, buf))
-          strcpy(buf, "-" );
+        strcpy(buf, "-" );
 
     return strlen(buf);
 }
@@ -330,53 +324,53 @@ int fmt_localip(ci_request_t *req, char *buf,int len, const char *param)
         return 0;
 
     if (!ci_conn_local_ip(req->connection, buf))
-          strcpy(buf, "-" );
+        strcpy(buf, "-" );
 
     return strlen(buf);
 }
 
 int fmt_icapmethod(ci_request_t *req, char *buf,int len, const char *param)
 {
-   int i;
-   const char *s = ci_method_string(req->type);
-   for(i=0;i<len && *s;i++,s++)
+    int i;
+    const char *s = ci_method_string(req->type);
+    for (i = 0; i < len && *s; i++,s++)
         buf[i] = *s;
-   return i;
+    return i;
 }
 
 int fmt_service(ci_request_t *req, char *buf,int len, const char *param)
 {
-   int i;
-   char *s = req->service;
-   for(i=0;i<len && *s;i++,s++)
+    int i;
+    char *s = req->service;
+    for (i = 0; i < len && *s; i++,s++)
         buf[i] = *s;
-   return i;
+    return i;
 }
 
 int fmt_username(ci_request_t *req, char *buf,int len, const char *param)
 {
-   int i;
-   char *s = req->user;
-   for(i=0;i<len && *s;i++,s++)
+    int i;
+    char *s = req->user;
+    for (i = 0; i < len && *s; i++,s++)
         buf[i] = *s;
-   return i;
+    return i;
 }
 
 int fmt_request(ci_request_t *req, char *buf,int len, const char *param)
 {
-   int i;
-   char *s = req->service;
-   for(i=0;i<len && *s;i++,s++)
+    int i;
+    char *s = req->service;
+    for (i = 0;  i< len && *s; i++,s++)
         buf[i] = *s;
 
-   if (req->args[0]!='\0' && i<len) {
-      buf[i] = '?';
-      s = req->args;
-      i++;
-      for(;i<len && *s;i++,s++)
-        buf[i] = *s;
-   }
-   return i;
+    if (req->args[0] != '\0' && i < len) {
+        buf[i] = '?';
+        s = req->args;
+        i++;
+        for (; i < len && *s; i++,s++)
+            buf[i] = *s;
+    }
+    return i;
 }
 
 int fmt_localtime(ci_request_t *req, char *buf,int len, const char *param)
@@ -388,7 +382,7 @@ int fmt_localtime(ci_request_t *req, char *buf,int len, const char *param)
     if (!len)
         return 0;
 
-    if (param && param[0]!='\0') {
+    if (param && param[0] != '\0') {
         tfmt = param;
     }
     t = time(&t);
@@ -405,7 +399,7 @@ int fmt_gmttime(ci_request_t *req, char *buf,int len, const char *param)
     if (!len)
         return 0;
 
-    if (param && param[0]!='\0') {
+    if (param && param[0] != '\0') {
         tfmt = param;
     }
     t = time(&t);
@@ -415,52 +409,50 @@ int fmt_gmttime(ci_request_t *req, char *buf,int len, const char *param)
 
 int fmt_icapstatus(ci_request_t *req, char *buf,int len, const char *param)
 {
-   return snprintf(buf, len, "%d", ci_error_code(req->return_code));
+    return snprintf(buf, len, "%d", ci_error_code(req->return_code));
 }
 
 
 int fmt_seconds(ci_request_t *req, char *buf,int len, const char *param)
 {
-   time_t tm;
-   time(&tm);
-   return snprintf(buf, len, "%ld", tm);
+    time_t tm;
+    time(&tm);
+    return snprintf(buf, len, "%ld", tm);
 }
 
 int fmt_httpclientip(ci_request_t *req, char *buf,int len, const char *param)
 {
-  const char *s;
-  int i;
-  if (!len)
-     return 0;
+    const char *s;
+    int i;
+    if (!len)
+        return 0;
 
-  if ((s = ci_headers_value(req->request_header, "X-Client-IP")) != NULL) {
-     for(i=0;i<len && *s!= '\0' && *s != '\r' && *s!='\n'; i++,s++)
-        buf[i] = *s;
-     return i;
-  }
-  else {
-     *buf = '-';
-     return 1;
-  }
+    if ((s = ci_headers_value(req->request_header, "X-Client-IP")) != NULL) {
+        for (i = 0; i < len && *s != '\0' && *s != '\r' && *s != '\n'; i++,s++)
+            buf[i] = *s;
+        return i;
+    } else {
+        *buf = '-';
+        return 1;
+    }
 
 }
 
 int fmt_httpserverip(ci_request_t *req, char *buf,int len, const char *param)
 {
-  const char *s;
-  int i;
-  if (!len)
-     return 0;
+    const char *s;
+    int i;
+    if (!len)
+        return 0;
 
-  if ((s = ci_headers_value(req->request_header, "X-Server-IP")) != NULL) {
-     for(i=0;i<len && *s!= '\0' && *s != '\r' && *s!='\n'; i++,s++)
-        buf[i] = *s;
-     return i;
-  }
-  else {
-     *buf = '-';
-     return 1;
-  }
+    if ((s = ci_headers_value(req->request_header, "X-Server-IP")) != NULL) {
+        for (i = 0; i < len && *s != '\0' && *s != '\r' && *s != '\n'; i++,s++)
+            buf[i] = *s;
+        return i;
+    } else {
+        *buf = '-';
+        return 1;
+    }
 }
 
 int fmt_http_req_url_o(ci_request_t *req, char *buf,int len, const char *param)
@@ -468,139 +460,145 @@ int fmt_http_req_url_o(ci_request_t *req, char *buf,int len, const char *param)
     if (!len)
         return 0;
 
-     return ci_http_request_url(req, buf, len);
+    return ci_http_request_url(req, buf, len);
 }
 
 int fmt_http_req_head_o(ci_request_t *req, char *buf,int len, const char *param)
 {
-  const char *s = NULL;
-  int i;
-  if (!len)
-     return 0;
+    const char *s = NULL;
+    int i;
+    if (!len)
+        return 0;
 
-  if (!param || param[0] == '\0') {
-      s = ci_http_request(req);
-  } else {
-      s = ci_http_request_get_header(req, param);
-  }
+    if (!param || param[0] == '\0') {
+        s = ci_http_request(req);
+    } else {
+        s = ci_http_request_get_header(req, param);
+    }
 
-  if (s)  {
-      for(i=0;i<len && *s!= '\0' && *s != '\r' && *s!='\n'; i++,s++)
-          buf[i] = *s;
-      return i;
-  } else {
-     *buf = '-';
-     return 1;
-  }
+    if (s)  {
+        for (i = 0; i < len && *s != '\0' && *s != '\r' && *s != '\n'; i++,s++)
+            buf[i] = *s;
+        return i;
+    } else {
+        *buf = '-';
+        return 1;
+    }
 }
 
 int fmt_http_res_head_o(ci_request_t *req, char *buf,int len, const char *param)
 {
-  const char *s = NULL;
-  int i;
-  ci_headers_list_t *http_resp_headers;
+    const char *s = NULL;
+    int i;
+    ci_headers_list_t *http_resp_headers;
 
-  if (!len)
-     return 0;
+    if (!len)
+        return 0;
 
-  if (!param || param[0] == '\0') {
-      http_resp_headers = ci_http_response_headers(req);
-      if (http_resp_headers && http_resp_headers->used)
-          s = http_resp_headers->headers[0];
-  } else {
-      s = ci_http_response_get_header(req, param);
-  }
+    if (!param || param[0] == '\0') {
+        http_resp_headers = ci_http_response_headers(req);
+        if (http_resp_headers && http_resp_headers->used)
+            s = http_resp_headers->headers[0];
+    } else {
+        s = ci_http_response_get_header(req, param);
+    }
 
-  if (s) {
-     for (i=0;i<len && *s!= '\0' && *s != '\r' && *s!='\n'; i++,s++)
-        buf[i] = *s;
-     return i;
-  } else {
-     *buf = '-';
-     return 1;
-  }
+    if (s) {
+        for (i = 0; i < len && *s != '\0' && *s != '\r' && *s != '\n'; i++,s++)
+            buf[i] = *s;
+        return i;
+    } else {
+        *buf = '-';
+        return 1;
+    }
 }
 
 
 int fmt_icap_req_head(ci_request_t *req, char *buf,int len, const char *param)
 {
-  const char *s = NULL;
-  int i;
-  if (!len)
-     return 0;
+    const char *s = NULL;
+    int i;
+    if (!len)
+        return 0;
 
-  if (!param || param[0] == '\0') {
-      if (req->request_header && req->request_header->used)
-          s = req->request_header->headers[0];
-  } else {
-      s = ci_headers_value(req->request_header, param);
-  }
+    if (!param || param[0] == '\0') {
+        if (req->request_header && req->request_header->used)
+            s = req->request_header->headers[0];
+    } else {
+        s = ci_headers_value(req->request_header, param);
+    }
 
-  if (s) {
-     for(i=0;i<len && *s!= '\0' && *s != '\r' && *s!='\n'; i++,s++)
-        buf[i] = *s;
-     return i;
-  } else {
-     *buf = '-';
-     return 1;
-  }
+    if (s) {
+        for (i = 0; i < len && *s != '\0' && *s != '\r' && *s != '\n'; i++,s++)
+            buf[i] = *s;
+        return i;
+    } else {
+        *buf = '-';
+        return 1;
+    }
 }
 
 int fmt_icap_res_head(ci_request_t *req, char *buf,int len, const char *param)
 {
-  const char *s = NULL;
-  int i;
-  if (!len)
-     return 0;
+    const char *s = NULL;
+    int i;
+    if (!len)
+        return 0;
 
-  if (!param || param[0] == '\0') {
-      if (req->response_header && req->response_header->used)
-          s = req->response_header->headers[0];
-  } else {
-      s = ci_headers_value(req->response_header, param);
-      /*if not found try xheaders which will also sent to user*/
-      if (!s && req->xheaders)
-          s = ci_headers_value(req->xheaders, param);
-  }
+    if (!param || param[0] == '\0') {
+        if (req->response_header && req->response_header->used)
+            s = req->response_header->headers[0];
+    } else {
+        s = ci_headers_value(req->response_header, param);
+        /*if not found try xheaders which will also sent to user*/
+        if (!s && req->xheaders)
+            s = ci_headers_value(req->xheaders, param);
+    }
 
-  if (s) {
-      for(i=0;i<len && *s!= '\0' && *s != '\r' && *s!='\n'; i++,s++)
-          buf[i] = *s;
-      return i;
-  } else {
-     *buf = '-';
-     return 1;
-  }
+    if (s) {
+        for (i = 0; i < len && *s != '\0' && *s != '\r' && *s != '\n'; i++,s++)
+            buf[i] = *s;
+        return i;
+    } else {
+        *buf = '-';
+        return 1;
+    }
 }
 
 
-int fmt_req_bytes_rcv(ci_request_t *req, char *buf,int len, const char *param) {
+int fmt_req_bytes_rcv(ci_request_t *req, char *buf,int len, const char *param)
+{
     return snprintf(buf, len, "%" PRINTF_OFF_T , (CAST_OFF_T) req->bytes_in);
 }
 
-int fmt_req_bytes_sent(ci_request_t *req, char *buf,int len, const char *param) {
+int fmt_req_bytes_sent(ci_request_t *req, char *buf,int len, const char *param)
+{
     return snprintf(buf, len, "%" PRINTF_OFF_T , (CAST_OFF_T) req->bytes_out);
 }
 
-int fmt_req_http_bytes_rcv(ci_request_t *req, char *buf,int len, const char *param) {
+int fmt_req_http_bytes_rcv(ci_request_t *req, char *buf,int len, const char *param)
+{
     return snprintf(buf, len, "%" PRINTF_OFF_T , (CAST_OFF_T) req->http_bytes_in);
 }
 
-int fmt_req_http_bytes_sent(ci_request_t *req, char *buf,int len, const char *param) {
+int fmt_req_http_bytes_sent(ci_request_t *req, char *buf,int len, const char *param)
+{
     return snprintf(buf, len, "%" PRINTF_OFF_T , (CAST_OFF_T) req->http_bytes_out);
 }
 
-int fmt_req_body_bytes_rcv(ci_request_t *req, char *buf,int len, const char *param) {
+int fmt_req_body_bytes_rcv(ci_request_t *req, char *buf,int len, const char *param)
+{
     return snprintf(buf, len, "%" PRINTF_OFF_T , (CAST_OFF_T) req->body_bytes_in);
 }
 
-int fmt_req_body_bytes_sent(ci_request_t *req, char *buf,int len, const char *param) {
+int fmt_req_body_bytes_sent(ci_request_t *req, char *buf,int len, const char *param)
+{
     return snprintf(buf, len, "%" PRINTF_OFF_T , (CAST_OFF_T) req->body_bytes_out);
 }
 
 int fmt_req_preview_hex(ci_request_t *req, char *buf,int len, const char *param)
 {
-    int  i, num, n, bytes; 
+    int  i, num, n, bytes;
 
     if (!len)
         return 0;
@@ -612,20 +610,19 @@ int fmt_req_preview_hex(ci_request_t *req, char *buf,int len, const char *param)
 
     if (param) {
         num = strtol(param, NULL, 10);
-    }
-    else
-       num = 5;
+    } else
+        num = 5;
     n = 0;
-    for (i=0; i<num && i < req->preview_data.used && len > 0; i++) {
+    for (i = 0; i < num && i < req->preview_data.used && len > 0; i++) {
         if (req->preview_data.buf[i] >= ' ' && req->preview_data.buf[i] <= '~') {
-            buf[n++] = req->preview_data.buf[i]; 
+            buf[n++] = req->preview_data.buf[i];
             len --;
         } else {
-	     bytes = snprintf(buf+n, len, "\\x%X",0xFF & (buf[i]));
-             if (bytes > len) bytes = len;
-             n += bytes;
-             len -= bytes;
-         }
+            bytes = snprintf(buf+n, len, "\\x%X",0xFF & (buf[i]));
+            if (bytes > len) bytes = len;
+            n += bytes;
+            len -= bytes;
+        }
     }
     return n;
 }
@@ -635,25 +632,25 @@ int fmt_req_preview_len(ci_request_t *req, char *buf, int len, const char *param
     if (!len)
         return 0;
 
-    if (req->preview >=0 )
+    if (req->preview >= 0)
         return snprintf(buf, len, "%d", req->preview_data.used);
-    
+
     *buf = '-';
     return 1;
 }
 
 int fmt_logstr(ci_request_t *req, char *buf,int len, const char *param)
 {
-   int i;
-   const char *s;
+    int i;
+    const char *s;
 
-   if (!req->log_str)
-       return 0;
+    if (!req->log_str)
+        return 0;
 
-   s = req->log_str;
-   for(i=0;i<len && *s;i++,s++)
+    s = req->log_str;
+    for (i = 0; i < len && *s; i++,s++)
         buf[i] = *s;
-   return i;
+    return i;
 }
 
 int fmt_req_attribute(ci_request_t *req, char *buf,int len, const char *param)
@@ -665,7 +662,7 @@ int fmt_req_attribute(ci_request_t *req, char *buf,int len, const char *param)
     if (! (s =ci_str_array_search(req->attributes, param)))
         return 0;
 
-    for(i=0; i<len && *s; i++, s++)
+    for (i = 0; i < len && *s; i++, s++)
         buf[i] = *s;
     return i;
 }
